# django-import-export-dramatiq
Fork of [django-import-export-celery] for [dramatiq]


## Requirements
* [django]
* [django-import-export]
* [django-author]
* [django-dramatiq]


## Installation
    pip install django-import-export-dramatiq
For further installation check [django-import-export-celery] and [django-dramatiq]

[django-import-export-celery]: https://github.com/auto-mat/django-import-export-celery
[dramatiq]: https://dramatiq.io
[django]: http://djangoproject.com/
[django-import-export]: https://github.com/django-import-export/django-import-export
[django-author]: https://github.com/lambdalisue/django-author
[django-dramatiq]: https://github.com/bogdanp/django_dramatiq
